==> dev.biuro-1.14.0.tar.gz: dev.biuro-1.14.0/wp-content/themes/biuro/single-job.php <==
<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Biuro
 * @since 1.0
 * @version 1.0
 */

get_header();
?>
<div id="content" class="l-content--position">

    <div class="l-content--position-inner">

        <main id="main" class="l-main l-main--position" itemscope="itemscope" itemtype="http://schema.org/JobPosting">
<?php
        $ID = get_the_id();

        $pod = pods( 'job', $ID );

        while ( have_posts() ) :
?>
            <meta itemprop="datePosted" content="<?php echo get_the_date('Y-m-d'); ?>" />

            <ul class="c-breadcrumbs">
                <li>
                    <a href="<?php echo pll_home_url(); ?>" ><?php _e('Main page', 'biuro'); ?></a>
                </li>
                <li class="c-breadcrumb--sep">
                    <svg width="4px" height="9.376px" class="c-ico--right">
                        <use href="#ico--right-slim"></use>
                    </svg>
                </li>
<?php
            global $positionsPage;

            if ($positionsPage):
?>
                <li>
                    <a href="<?php echo $positionsPage; ?>"><?php _e('Job offers', 'biuro'); ?></a>
                </li>
                <li class="c-breadcrumb--sep">
                    <svg width="4px" height="9.376px" class="c-ico--right">
                        <use href="#ico--right-slim"></use>
                    </svg>
                </li>
<?php
            endif;
?>
                <li class="c-breadcrumb--active">
                    <a href="<?php echo the_permalink(); ?>"><?php the_title(); ?></a>
                </li>
            </ul>

            <h1 class="c-job--title" itemprop="title"><?php the_title(); ?></h1>
<?php

    function getCategory($ID, $str) {
        $res = array(
            'name' => '',
            'pageURL' => '',
        );

        $termID = get_post_meta($ID, "_yoast_wpseo_primary_{$str}", true);

        if (isset($termID)) {
            $pages = getOptions($str);

            $options = array_filter($pages, function ($pages) use ($termID) { return ($pages['termID'] == $termID); } );

            if (count($options) > 0):

                foreach ($options as &$page) :
                    if (isset($page['name'])):
                        $res['name'] = $page['name'];
                    endif;

                    if (isset($page['pageID'])):
                        $res['pageURL'] = get_page_link( $page['pageID'] );
                    else:
                        $res['pageURL'] = ($str == 'city') ? '/?city=' . $res['name'] . '&s=' : '/?city=&s=' . $res['name'];
                    endif;
                endforeach;

            else:

                $term = get_term( $termID, $str );

                if (isset($term) && isset($term->name)):
                    $res['name'] = $term->name;
                endif;

                $page = get_term_meta( $termID, 'page-id', true);

                if (isset($page) && isset($page['ID'])):
                    $res['pageURL'] = get_page_link( $page['ID'] );
                else:
                    $res['pageURL'] = ($str == 'city') ? '/?city=' . $term->name . '&s=' : '/?city=&s=' . $term->name;
                endif;

            endif;
        }

        return $res;
    }

        $location = $pod->field('division-id');
        $streetAddress = '';
        $postalCode = '';
        $addressRegion = '';

        if ($location) :
            $division = pods( 'division', $location['ID']);
            $divisionCity = $division->field('city', true);

            $addressRegion = $divisionCity['name'] ? $divisionCity['name'] : '';
            $postalCode = $division->field('postal-code', true);
            $streetAddress = $division->field('title', true);
        endif;

        if ( $addressRegion != '' && $postalCode != '' && $streetAddress != '' ) :
?>
        <div itemprop="jobLocation" itemscope itemtype="http://schema.org/Place">
            <div itemprop="address" itemscope itemtype="http://schema.org/PostalAddress">
                <meta itemprop="streetAddress" content="<?php echo $streetAddress; ?>" />
                <meta itemprop="addressLocality" content="<?php echo $streetAddress; ?>" />
                <meta itemprop="addressRegion" content="<?php echo $addressRegion; ?>" />
                <meta itemprop="postalCode" content="<?php echo $postalCode; ?>" />
            </div>
        </div>
<?php
        elseif ( is_active_sidebar( 'postal_address' ) ) :
            dynamic_sidebar( 'postal_address' );
        endif;

        $occupationalCategories = get_the_terms( $ID, 'field' );

        if (is_array($occupationalCategories)) :
            foreach ($occupationalCategories as &$occupationalCategory) :
?>
            <meta itemprop="occupationalCategory" content="<?php echo $occupationalCategory->name ; ?>" />
<?php
            endforeach;
        endif;

        $employmentTypes = get_the_terms( $ID, 'type' );

        if (is_array($employmentTypes)) :
            foreach ($employmentTypes as &$employmentType) :
?>
            <meta itemprop="employmentType" content="<?php echo $employmentType->name; ?>" />
<?php
            endforeach;
        endif;
?>
            <ul class="c-categories">
<?php
            $city = getCategory($ID, 'city');

            if ($city['name'] != ''):
?>
                <li>
                    <a href="<?php echo $city['pageURL']; ?>"><?php echo $city['name']; ?></a>
                </li>
<?php
            endif;

            $field = getCategory($ID, 'field');

            if ($field['name'] != ''):
                if ($city['name'] != ''):
                    echo '<li class="c-categories--sep">/</li>';
                endif;
?>
                <li>
                    <a href="<?php echo $field['pageURL']; ?>" ><?php echo $field['name']; ?></a>
                </li>
<?php
            endif;

            $types = wp_get_post_terms( $ID, 'type', array('orderby' => 'count', 'order' => 'DESC'));
            $options = getOptions('type');

            usort($options, function($a, $b) {
                return $a['no'] < $b['no'];
            });

            $type = array(
                'name' => '',
                'pageURL' => '',
            );

            foreach ($options as &$option) :
                foreach ($types as &$page) :
                    if ($page->term_id == $option['termID']):
                        if (isset($page->name)):
                            $type['name'] = $page->name;
                        endif;

                        if (isset($option['pageID'])):
                            $type['pageURL'] = get_page_link( $option['pageID'] );
                        else:
                            $type['pageURL'] = '/?city=&s=' . $type['name'];
                        endif;

                        break 2;
                    endif;

                endforeach;
            endforeach;

            if ($type['name'] != ''):
                if ($field['name'] != '' || $city['name'] != ''):
?>
                <li class="c-categories--sep">/</li>
<?php
                endif;
?>
                <li>
                    <a href="<?php echo $type['pageURL']; ?>" ><?php echo $type['name']; ?></a>
                </li>
<?php
            endif;
?>
            </ul>

            <div class="c-job--content" itemprop="description">
<?php
                the_post();
                the_content();
?>
            </div>
<?php
        endwhile;
?>
        <br>

        <div class="c-job--content">
<?php
        if (!is_array($pod->field( 'salary_from' )) && $pod->field( 'salary_from' ) > 0 || !is_array($pod->field( 'salary_to' )) && $pod->field( 'salary_to' ) > 0):

            if ($pod->field( 'salary_from' ) > 0 || $pod->field( 'salary_to' ) > 0):
?>
                <div itemprop="baseSalary" itemscope itemtype="http://schema.org/MonetaryAmount">
                    <meta itemprop="currency" content="EUR" />
<?php
                    if ($pod->field( 'salary_from' ) > 0 && $pod->field( 'salary_to' ) > 0):
?>                    <meta itemprop="minValue" content="<?php echo $pod->field( 'salary_from' ); ?>" />
                        <meta itemprop="maxValue" content="<?php echo $pod->field( 'salary_to' ); ?>" />
<?php          elseif ($pod->field( 'salary_from' ) > 0):
?>                    <meta itemprop="value" content="<?php echo $pod->field( 'salary_from' ); ?>" />
<?php          elseif ($pod->field( 'salary_to' ) > 0):
?>                    <meta itemprop="value" content="<?php echo $pod->field( 'salary_to' ); ?>" />
<?php          endif;
?>             </div>
<?php

                if (!$pod->field( 'hide-salary' )):

                    echo '<b>' . __('Salary', 'biuro') . ':</b> ';

                    if ($pod->field( 'salary_from' ) > 0):
                        echo __('from', 'biuro') . ' ' . $pod->field( 'salary_from' ) . ' ';
                    endif;

                    if ($pod->field( 'salary_to' ) > 0):
                        echo __('to', 'biuro') . ' ' . $pod->field( 'salary_to' ) . ' ';
                    endif;

                    _e('(neto)', 'biuro');

                endif;

            endif;
        endif;

        if ( is_active_sidebar( 'hiring_organization' ) ) :
            dynamic_sidebar( 'hiring_organization' );
        endif;

        $validPosition = date_i18n( 'Y-m-d', strtotime( $pod->field( 'valid' ) ) ) >= date('Y-m-d') ? true : false;
?>
            <b><?php _e('Valid till', 'biuro'); ?>:</b> <time itemprop="validThrough" datetime="<?php echo date_i18n( 'Y-m-d', strtotime( $pod->field( 'valid' ) ) ); ?>"><?php echo date_i18n( get_option( 'date_format' ), strtotime( $pod->field( 'valid' ) ) ); ?></time>

        </div>

<?php

    global $recommendPage;

    if ($validPosition):
 ?>
        <div class="c-job--action">
            <button type="button" class="js-inititate-position-form o-btn c-btn--main c-btn--fit" name="submit" value="1" data-id="action--form"><?php _e('Apply', 'biuro'); ?></button>
<?php
        if ($recommendPage):
?>
            <a href="<?php echo $recommendPage; ?>" class="o-btn c-btn--slim c-btn--fit"><?php _e('Recommend a friend', 'biuro'); ?></a>
<?php
        endif;
 ?>
        </div>
<?php
    endif;
 ?>
        </main><!-- .l-main -->

        <aside class="l-aside--position">
<?php
        if ($validPosition):
            get_template_part( 'template-parts/layout/aside', 'job' );
        else:
            get_template_part( 'template-parts/layout/aside', 'job-inactive' );
        endif;
?>
        </aside><!-- .l-aside -->

    </div><!-- .l-content -position-inner -->

</div><!-- #content -->

<?php get_footer();

==> dev.biuro-1.15.0.tar.gz: dev.biuro-1.15.0/wp-content/themes/biuro/single-job.php <==
<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Biuro
 * @since 1.0
 * @version 1.0
 */

get_header();
?>
<div id="content" class="l-content--position">

    <div class="l-content--position-inner">

        <main id="main" class="l-main l-main--position" itemscope="itemscope" itemtype="http://schema.org/JobPosting">
<?php
        $ID = get_the_id();

        $pod = pods( 'job', $ID );

        while ( have_posts() ) :
?>
            <meta itemprop="datePosted" content="<?php echo get_the_date('Y-m-d'); ?>" />

            <ul class="c-breadcrumbs">
                <li>
                    <a href="<?php echo pll_home_url(); ?>" ><?php _e('Main page', 'biuro'); ?></a>
                </li>
                <li class="c-breadcrumb--sep">
                    <svg width="4px" height="9.376px" class="c-ico--right">
                        <use href="#ico--right-slim"></use>
                    </svg>
                </li>
<?php
            global $positionsPage;

            if ($positionsPage):
?>
                <li>
                    <a href="<?php echo $positionsPage; ?>"><?php _e('Job offers', 'biuro'); ?></a>
                </li>
                <li class="c-breadcrumb--sep">
                    <svg width="4px" height="9.376px" class="c-ico--right">
                        <use href="#ico--right-slim"></use>
                    </svg>
                </li>
<?php
            endif;
?>
                <li class="c-breadcrumb--active">
                    <a href="<?php echo the_permalink(); ?>"><?php the_title(); ?></a>
                </li>
            </ul>

            <h1 class="c-job--title" itemprop="title"><?php the_title(); ?></h1>
<?php

    function getCategory($ID, $str) {
        $res = array(
            'name' => '',
            'pageURL' => '',
        );

        $termID = get_post_meta($ID, "_yoast_wpseo_primary_{$str}", true);

        if (isset($termID)) {
            $pages = getOptions($str);

            $options = array_filter($pages, function ($pages) use ($termID) { return ($pages['termID'] == $termID); } );

            if (count($options) > 0):

                foreach ($options as &$page) :
                    if (isset($page['name'])):
                        $res['name'] = $page['name'];
                    endif;

                    if (isset($page['pageID'])):
                        $res['pageURL'] = get_page_link( $page['pageID'] );
                    else:
                        $res['pageURL'] = ($str == 'city') ? '/?city=' . $res['name'] . '&s=' : '/?city=&s=' . $res['name'];
                    endif;
                endforeach;

            else:

                $term = get_term( $termID, $str );

                if (isset($term) && isset($term->name)):
                    $res['name'] = $term->name;
                endif;

                $page = get_term_meta( $termID, 'page-id', true);

                if (isset($page) && isset($page['ID'])):
                    $res['pageURL'] = get_page_link( $page['ID'] );
                else:
                    $res['pageURL'] = ($str == 'city') ? '/?city=' . $term->name . '&s=' : '/?city=&s=' . $term->name;
                endif;

            endif;
        }

        return $res;
    }

        $location = $pod->field('division-id');
        $streetAddress = '';
        $postalCode = '';
        $addressRegion = '';

        if ($location) :
            $division = pods( 'division', $location['ID']);
            $divisionCity = $division->field('city', true);

            $addressRegion = isset($divisionCity->name) ? $divisionCity['name'] : '';
            $postalCode = $division->field('postal-code', true);
            $streetAddress = $division->field('title', true);
        endif;

        if ( $addressRegion != '' && $postalCode != '' && $streetAddress != '' ) :
?>
        <div itemprop="jobLocation" itemscope itemtype="http://schema.org/Place">
            <div itemprop="address" itemscope itemtype="http://schema.org/PostalAddress">
                <meta itemprop="streetAddress" content="<?php echo $streetAddress; ?>" />
                <meta itemprop="addressLocality" content="<?php echo $streetAddress; ?>" />
                <meta itemprop="addressRegion" content="<?php echo $addressRegion; ?>" />
                <meta itemprop="postalCode" content="<?php echo $postalCode; ?>" />
            </div>
        </div>
<?php
        elseif ( is_active_sidebar( 'postal_address' ) ) :
            dynamic_sidebar( 'postal_address' );
        endif;

        $occupationalCategories = get_the_terms( $ID, 'field' );

        if (is_array($occupationalCategories)) :
            foreach ($occupationalCategories as &$occupationalCategory) :
?>
            <meta itemprop="occupationalCategory" content="<?php echo $occupationalCategory->name ; ?>" />
<?php
            endforeach;
        endif;

        $employmentTypes = get_the_terms( $ID, 'type' );

        if (is_array($employmentTypes)) :
            foreach ($employmentTypes as &$employmentType) :
?>
            <meta itemprop="employmentType" content="<?php echo $employmentType->name; ?>" />
<?php
            endforeach;
        endif;
?>
            <ul class="c-categories">
<?php
            $city = getCategory($ID, 'city');

            if ($city['name'] != ''):
?>
                <li>
                    <a href="<?php echo $city['pageURL']; ?>"><?php echo $city['name']; ?></a>
                </li>
<?php
            endif;

            $field = getCategory($ID, 'field');

            if ($field['name'] != ''):
                if ($city['name'] != ''):
                    echo '<li class="c-categories--sep">/</li>';
                endif;
?>
                <li>
                    <a href="<?php echo $field['pageURL']; ?>" ><?php echo $field['name']; ?></a>
                </li>
<?php
            endif;

            $types = wp_get_post_terms( $ID, 'type', array('orderby' => 'count', 'order' => 'DESC'));
            $options = getOptions('type');

            usort($options, function($a, $b) {
                return $a['no'] < $b['no'];
            });

            $type = array(
                'name' => '',
                'pageURL' => '',
            );

            foreach ($options as &$option) :
                foreach ($types as &$page) :
                    if ($page->term_id == $option['termID']):
                        if (isset($page->name)):
                            $type['name'] = $page->name;
                        endif;

                        if (isset($option['pageID'])):
                            $type['pageURL'] = get_page_link( $option['pageID'] );
                        else:
                            $type['pageURL'] = '/?city=&s=' . $type['name'];
                        endif;

                        break 2;
                    endif;

                endforeach;
            endforeach;

            if ($type['name'] != ''):
                if ($field['name'] != '' || $city['name'] != ''):
?>
                <li class="c-categories--sep">/</li>
<?php
                endif;
?>
                <li>
                    <a href="<?php echo $type['pageURL']; ?>" ><?php echo $type['name']; ?></a>
                </li>
<?php
            endif;
?>
            </ul>

            <div class="c-job--content" itemprop="description">
<?php
                the_post();
                the_content();
?>
            </div>
<?php
        endwhile;
?>
        <br>

        <div class="c-job--content">
<?php
        if (!is_array($pod->field( 'salary_from' )) && $pod->field( 'salary_from' ) > 0 || !is_array($pod->field( 'salary_to' )) && $pod->field( 'salary_to' ) > 0):

            if ($pod->field( 'salary_from' ) > 0 || $pod->field( 'salary_to' ) > 0):
?>
                <div itemprop="baseSalary" itemscope itemtype="http://schema.org/MonetaryAmount">
                    <meta itemprop="currency" content="EUR" />
<?php
                    if ($pod->field( 'salary_from' ) > 0 && $pod->field( 'salary_to' ) > 0):
?>                    <meta itemprop="minValue" content="<?php echo $pod->field( 'salary_from' ); ?>" />
                        <meta itemprop="maxValue" content="<?php echo $pod->field( 'salary_to' ); ?>" />
<?php          elseif ($pod->field( 'salary_from' ) > 0):
?>                    <meta itemprop="value" content="<?php echo $pod->field( 'salary_from' ); ?>" />
<?php          elseif ($pod->field( 'salary_to' ) > 0):
?>                    <meta itemprop="value" content="<?php echo $pod->field( 'salary_to' ); ?>" />
<?php          endif;
?>             </div>
<?php

                if (!$pod->field( 'hide-salary' )):

                    echo '<b>' . __('Salary', 'biuro') . ':</b> ';

                    if ($pod->field( 'salary_from' ) > 0):
                        echo __('from', 'biuro') . ' ' . $pod->field( 'salary_from' ) . ' ';
                    endif;

                    if ($pod->field( 'salary_to' ) > 0):
                        echo __('to', 'biuro') . ' ' . $pod->field( 'salary_to' ) . ' ';
                    endif;

                    _e('(neto)', 'biuro');

                endif;

            endif;
        endif;

        if ( is_active_sidebar( 'hiring_organization' ) ) :
            dynamic_sidebar( 'hiring_organization' );
        endif;

        $validPosition = date_i18n( 'Y-m-d', strtotime( $pod->field( 'valid' ) ) ) >= date('Y-m-d') ? true : false;
?>
            <b><?php _e('Valid till', 'biuro'); ?>:</b> <time itemprop="validThrough" datetime="<?php echo date_i18n( 'Y-m-d', strtotime( $pod->field( 'valid' ) ) ); ?>"><?php echo date_i18n( get_option( 'date_format' ), strtotime( $pod->field( 'valid' ) ) ); ?></time>

        </div>

<?php

    global $recommendPage;

    if ($validPosition):
 ?>
        <div class="c-job--action">
            <button type="button" class="js-inititate-position-form o-btn c-btn--main c-btn--fit" name="submit" value="1" data-id="action--form"><?php _e('Apply', 'biuro'); ?></button>
<?php
        if ($recommendPage):
?>
            <a href="<?php echo $recommendPage; ?>" class="o-btn c-btn--slim c-btn--fit"><?php _e('Recommend a friend', 'biuro'); ?></a>
<?php
        endif;
 ?>
        </div>
<?php
    endif;
 ?>
        </main><!-- .l-main -->

        <aside class="l-aside--position">
<?php
        if ($validPosition):
            get_template_part( 'template-parts/layout/aside', 'job' );
        else:
            get_template_part( 'template-parts/layout/aside', 'job-inactive' );
        endif;
?>
        </aside><!-- .l-aside -->

    </div><!-- .l-content -position-inner -->

</div><!-- #content -->

<?php get_footer();
